==> jc-1.4.0.tar.gz: polyglot/util/IdentityKey.h <==
// public class polyglot.util.IdentityKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 81fe6368f86e3de1 polyglot_util_IdentityKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_IdentityKey_H_
#define _JC_polyglot_util_IdentityKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_util_IdentityKey$sub_refs	_jc_polyglot_util_IdentityKey$sub_refs;
typedef struct _jc_polyglot_util_IdentityKey$sub_nonrefs	_jc_polyglot_util_IdentityKey$sub_nonrefs;
typedef struct _jc_polyglot_util_IdentityKey$refs	_jc_polyglot_util_IdentityKey$refs;
typedef struct _jc_polyglot_util_IdentityKey$nonrefs	_jc_polyglot_util_IdentityKey$nonrefs;
typedef struct _jc_polyglot_util_IdentityKey$object	_jc_polyglot_util_IdentityKey$object;

typedef const struct _jc_polyglot_util_IdentityKey$vmethods	_jc_polyglot_util_IdentityKey$vmethods;
typedef const struct _jc_polyglot_util_IdentityKey$vtable	_jc_polyglot_util_IdentityKey$vtable;
typedef const struct _jc_polyglot_util_IdentityKey$vtype	_jc_polyglot_util_IdentityKey$vtype;

// Constructors
extern void _jc_polyglot_util_IdentityKey$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_polyglot_util_IdentityKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_util_IdentityKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_IdentityKey$method$object$f7b1c7a013024639(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_IdentityKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_util_IdentityKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_util_IdentityKey$method_info$object$f7b1c7a013024639;

// Virtual methods structure
struct _jc_polyglot_util_IdentityKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *);
	struct _jc_java_lang_Object$object	*(*object$f7b1c7a013024639)(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *);
};

// Vtable
struct _jc_polyglot_util_IdentityKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_IdentityKey$vmethods	polyglot_util_IdentityKey;
};

// Vtype
struct _jc_polyglot_util_IdentityKey$vtype {
	_jc_type			type;
	_jc_polyglot_util_IdentityKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_IdentityKey$sub_refs {
	struct _jc_java_lang_Object$object	*obj;
};

// Reference instance fields (object)
struct _jc_polyglot_util_IdentityKey$refs {
    _jc_polyglot_util_IdentityKey$sub_refs	polyglot_util_IdentityKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_IdentityKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_IdentityKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_IdentityKey$sub_nonrefs	polyglot_util_IdentityKey;
};

// Object instance structure
struct _jc_polyglot_util_IdentityKey$object {
	_jc_polyglot_util_IdentityKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_IdentityKey$vtype	*vtype;
	_jc_polyglot_util_IdentityKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_IdentityKey$vtype _jc_polyglot_util_IdentityKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_IdentityKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_IdentityKey$class_object;

#endif	/* _JC_polyglot_util_IdentityKey_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/IdentityKey.h <==
// public class polyglot.util.IdentityKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 81fe6368f86e3de1 polyglot_util_IdentityKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_IdentityKey_H_
#define _JC_polyglot_util_IdentityKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_util_IdentityKey$sub_refs	_jc_polyglot_util_IdentityKey$sub_refs;
typedef struct _jc_polyglot_util_IdentityKey$sub_nonrefs	_jc_polyglot_util_IdentityKey$sub_nonrefs;
typedef struct _jc_polyglot_util_IdentityKey$refs	_jc_polyglot_util_IdentityKey$refs;
typedef struct _jc_polyglot_util_IdentityKey$nonrefs	_jc_polyglot_util_IdentityKey$nonrefs;
typedef struct _jc_polyglot_util_IdentityKey$object	_jc_polyglot_util_IdentityKey$object;

typedef const struct _jc_polyglot_util_IdentityKey$vmethods	_jc_polyglot_util_IdentityKey$vmethods;
typedef const struct _jc_polyglot_util_IdentityKey$vtable	_jc_polyglot_util_IdentityKey$vtable;
typedef const struct _jc_polyglot_util_IdentityKey$vtype	_jc_polyglot_util_IdentityKey$vtype;

// Constructors
extern void _jc_polyglot_util_IdentityKey$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_IdentityKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_util_IdentityKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_IdentityKey$method$object$f7b1c7a013024639(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_IdentityKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_util_IdentityKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_util_IdentityKey$method_info$object$f7b1c7a013024639;

// Virtual methods structure
struct _jc_polyglot_util_IdentityKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*object$f7b1c7a013024639)(_jc_env *, struct _jc_polyglot_util_IdentityKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_IdentityKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_IdentityKey$vmethods	polyglot_util_IdentityKey;
};

// Vtype
struct _jc_polyglot_util_IdentityKey$vtype {
	_jc_type			type;
	_jc_polyglot_util_IdentityKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_IdentityKey$sub_refs {
	struct _jc_java_lang_Object$object	*obj;
};

// Reference instance fields (object)
struct _jc_polyglot_util_IdentityKey$refs {
    _jc_polyglot_util_IdentityKey$sub_refs	polyglot_util_IdentityKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_IdentityKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_IdentityKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_IdentityKey$sub_nonrefs	polyglot_util_IdentityKey;
};

// Object instance structure
struct _jc_polyglot_util_IdentityKey$object {
	_jc_polyglot_util_IdentityKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_IdentityKey$vtype	*vtype;
	_jc_polyglot_util_IdentityKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_IdentityKey$vtype _jc_polyglot_util_IdentityKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_IdentityKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_IdentityKey$class_object;

#endif	/* _JC_polyglot_util_IdentityKey_H_ */
